@@ -791,6 +791,51 @@ CREATE TABLE tmp2 AS (SELECT * FROM tmp);
 DROP TABLE tmp;
 DROP TABLE tmp2;
 
+--
+-- Test MISC
+SET pgaudit.log = 'MISC';
+SET pgaudit.log_level = 'notice';
+SET pgaudit.log_client = ON;
+SET pgaudit.log_relation = ON;
+SET pgaudit.log_parameter = ON;
+
+CREATE ROLE alice;
+
+SET ROLE alice;
+CREATE TABLE t (a int, b text);
+SET search_path TO test, public;
+
+INSERT INTO t VALUES (1, 'misc');
+
+VACUUM t;
+RESET ROLE;
+
+--
+-- Test MISC_SET
+SET pgaudit.log = 'MISC_SET';
+
+SET ROLE alice;
+SET search_path TO public;
+
+INSERT INTO t VALUES (2, 'misc_set');
+
+VACUUM t;
+RESET ROLE;
+
+--
+-- Test ALL, -MISC, MISC_SET
+SET pgaudit.log = 'ALL, -MISC, MISC_SET';
+
+SET search_path TO public;
+
+INSERT INTO t VALUES (3, 'all, -misc, misc_set');
+
+VACUUM t;
+
+RESET ROLE;
+DROP TABLE public.t;
+DROP ROLE alice;
+
 --
 -- Test PARTITIONED table
 CREATE TABLE h(x int ,y int) PARTITION BY HASH(x);
@@ -837,11 +882,11 @@ DROP FUNCTION upper(text);
 
 -- Create/drop extension. Note that the log level here must be warning because the create extension code will reset any higher log
 -- levels like notice
-SET pgaudit.log = 'all';
+SET pgaudit.log = 'all,-misc_set';
 SET pgaudit.log_level = 'warning';
 
 CREATE EXTENSION pg_stat_statements;
-ALTER EXTENSION pg_stat_statements UPDATE TO '1.6';
+ALTER EXTENSION pg_stat_statements UPDATE TO '1.7';
 DROP EXTENSION pg_stat_statements;
 
 SET pgaudit.log_level = 'notice';
